@@ -1,4 +1,5 @@
 <?php
+
 /*
  * RoleFactory.php
  *
@@ -26,13 +27,13 @@
 namespace Database\Factories;
 
 use Illuminate\Database\Eloquent\Factories\Factory;
-use Silber\Bouncer\Database\Role;
+use Spatie\Permission\Models\Role;
 
 class RoleFactory extends Factory
 {
     protected $model = Role::class;
 
-    public function definition()
+    public function definition(): array
     {
         return [
             'name' => $this->faker->text(),
