@@ -3,14 +3,14 @@
 use Illuminate\Database\Migrations\Migration;
 use Illuminate\Database\Schema\Blueprint;
 
-class CreatePdbIxTable extends Migration
+return new class extends Migration
 {
     /**
      * Run the migrations.
      *
      * @return void
      */
-    public function up()
+    public function up(): void
     {
         Schema::create('pdb_ix', function (Blueprint $table) {
             $table->increments('pdb_ix_id');
@@ -26,8 +26,8 @@ class CreatePdbIxTable extends Migration
      *
      * @return void
      */
-    public function down()
+    public function down(): void
     {
         Schema::drop('pdb_ix');
     }
-}
+};
