@@ -3,14 +3,14 @@
 use Illuminate\Database\Migrations\Migration;
 use Illuminate\Database\Schema\Blueprint;
 
-class CreateNotificationsAttribsIndex extends Migration
+return new class extends Migration
 {
     /**
      * Run the migrations.
      *
      * @return void
      */
-    public function up()
+    public function up(): void
     {
         Schema::table('notifications_attribs', function (Blueprint $table) {
             $table->index(['notifications_id', 'user_id']);
@@ -22,10 +22,10 @@ class CreateNotificationsAttribsIndex extends Migration
      *
      * @return void
      */
-    public function down()
+    public function down(): void
     {
         Schema::table('notifications_attribs', function (Blueprint $table) {
             $table->dropIndex(['notifications_id', 'user_id']);
         });
     }
-}
+};
