@@ -15,7 +15,6 @@ use App\Models\StateTranslation;
 use Illuminate\Support\Facades\Log;
 use Illuminate\Support\Str;
 use LibreNMS\Enum\Severity;
-use LibreNMS\Util\StringHelpers;
 
 /**
  * Parse cli discovery or poller modules and set config for this run
@@ -501,37 +500,6 @@ function hytera_h2f($number, $nd)
     return number_format($floatfinal, $nd, '.', '');
 }
 
-function q_bridge_bits2indices($hex_data): array
-{
-    /* convert hex string to an array of 1-based indices of the nonzero bits
-     * ie. '9a00' -> '100110100000' -> array(1, 4, 5, 7)
-    */
-    $hex_data = str_replace([' ', "\n"], '', $hex_data);
-
-    // we need an even number of digits for hex2bin
-    if (strlen($hex_data) % 2 === 1) {
-        $hex_data = '0' . $hex_data;
-    }
-
-    if (! StringHelpers::isHex($hex_data)) {
-        return [];
-    }
-
-    $value = hex2bin($hex_data);
-    $length = strlen($value);
-    $indices = [];
-    for ($i = 0; $i < $length; $i++) {
-        $byte = ord($value[$i]);
-        for ($j = 7; $j >= 0; $j--) {
-            if ($byte & (1 << $j)) {
-                $indices[] = 8 * $i + 8 - $j;
-            }
-        }
-    }
-
-    return $indices;
-}
-
 /**
  * Function to generate PeeringDB Cache
  */
