@@ -24,8 +24,8 @@
  * @author     Thomas Berberich <sourcehhdoctor@gmail.com>
  */
 
+use App\Facades\LibrenmsConfig;
 use LibreNMS\Alerting\QueryBuilderParser;
-use LibreNMS\Config;
 
 header('Content-type: application/json');
 
@@ -42,20 +42,20 @@ if (is_numeric($rule_id)) {
     $rule = dbFetchRow('SELECT * FROM alert_rules where id=?', [$rule_id]);
 
     $default_extra = [
-        'mute' => Config::get('alert_rule.mute_alerts'),
-        'count' => Config::get('alert_rule.max_alerts'),
-        'delay' => 60 * Config::get('alert_rule.delay'),
-        'invert' => Config::get('alert_rule.invert_rule_match'),
-        'interval' => 60 * Config::get('alert_rule.interval'),
-        'recovery' => Config::get('alert_rule.recovery_alerts'),
-        'acknowledgement' => Config::get('alert_rule.acknowledgement_alerts'),
+        'mute' => LibrenmsConfig::get('alert_rule.mute_alerts'),
+        'count' => LibrenmsConfig::get('alert_rule.max_alerts'),
+        'delay' => 60 * LibrenmsConfig::get('alert_rule.delay'),
+        'invert' => LibrenmsConfig::get('alert_rule.invert_rule_match'),
+        'interval' => 60 * LibrenmsConfig::get('alert_rule.interval'),
+        'recovery' => LibrenmsConfig::get('alert_rule.recovery_alerts'),
+        'acknowledgement' => LibrenmsConfig::get('alert_rule.acknowledgement_alerts'),
     ];
     $output = [
         'status' => 'ok',
         'name' => $rule['name'] . ' - Copy',
         'builder' => QueryBuilderParser::fromJson($rule['builder']),
         'extra' => array_replace($default_extra, (array) json_decode($rule['extra'])),
-        'severity' => $rule['severity'] ?: Config::get('alert_rule.severity'),
+        'severity' => $rule['severity'] ?: LibrenmsConfig::get('alert_rule.severity'),
         'invert_map' => $rule['invert_map'],
     ];
 } else {
