@@ -34,16 +34,12 @@ $array = [
 
 $i = 0;
 
-if (Rrd::checkRrdExists($rrd_filename)) {
-    foreach ($array as $ds => $var) {
-        $rrd_list[$i]['filename'] = $rrd_filename;
-        $rrd_list[$i]['descr'] = $var['descr'];
-        $rrd_list[$i]['ds'] = $ds;
-        $rrd_list[$i]['colour'] = $var['colour'];
-        $i++;
-    }
-} else {
-    echo "file missing: $rrd_filename";
+foreach ($array as $ds => $var) {
+    $rrd_list[$i]['filename'] = $rrd_filename;
+    $rrd_list[$i]['descr'] = $var['descr'];
+    $rrd_list[$i]['ds'] = $ds;
+    $rrd_list[$i]['colour'] = $var['colour'];
+    $i++;
 }
 
 require 'includes/html/graphs/generic_v3_multiline_float.inc.php';
