@@ -22,7 +22,7 @@ if (Rrd::checkRrdExists($rrd_filename)) {
         ];
     }
 } else {
-    echo "file missing: $file";
+    throw new \LibreNMS\Exceptions\RrdGraphException("No Data file $rrd_filename");
 }
 
 require 'includes/html/graphs/generic_multi_line_exact_numbers.inc.php';
