@@ -3,9 +3,9 @@
 require 'includes/html/graphs/common.inc.php';
 
 // $rrd_options .= " -l 0 -E ";
-$rrdfilename = rrd_name($device['hostname'], 'ubnt-airfiber-mib');
+$rrdfilename = Rrd::name($device['hostname'], 'ubnt-airfiber-mib');
 
-if (rrdtool_check_rrd_exists($rrdfilename)) {
+if (Rrd::checkRrdExists($rrdfilename)) {
     $rrd_options .= " COMMENT:'Packets                Now      Min     Max\\n'";
     $rrd_options .= ' DEF:txpktsAll=' . $rrdfilename . ':txpktsAll:AVERAGE ';
     $rrd_options .= " LINE1:txpktsAll#CC0000:'Tx Packets     ' ";
