@@ -3,9 +3,9 @@
 require 'includes/html/graphs/common.inc.php';
 
 // $rrd_options .= " -l 0 -E ";
-$rrdfilename = rrd_name($device['hostname'], 'ubnt-airfiber-mib');
+$rrdfilename = Rrd::name($device['hostname'], 'ubnt-airfiber-mib');
 
-if (rrdtool_check_rrd_exists($rrdfilename)) {
+if (Rrd::checkRrdExists($rrdfilename)) {
     $rrd_options .= " COMMENT:'Celcius               Now     Min      Max\\n'";
     $rrd_options .= ' DEF:radio0TempC=' . $rrdfilename . ':radio0TempC:AVERAGE ';
     $rrd_options .= ' DEF:radio1TempC=' . $rrdfilename . ':radio1TempC:AVERAGE ';
