@@ -1,7 +1,7 @@
 <?php
 
+use App\Facades\LibrenmsConfig;
 use Illuminate\Support\Str;
-use LibreNMS\Config;
 use LibreNMS\Data\Graphing\GraphParameters;
 use LibreNMS\Enum\ImageFormat;
 
@@ -41,15 +41,15 @@ try {
         $env['TZ'] = session('preferences.timezone');
     }
 
-    require Config::get('install_dir') . "/includes/html/graphs/$type/auth.inc.php";
+    require LibrenmsConfig::get('install_dir') . "/includes/html/graphs/$type/auth.inc.php";
 
     if ($auth && is_customoid_graph($type, $subtype)) {
         $unit = $vars['unit'];
-        include Config::get('install_dir') . '/includes/html/graphs/customoid/customoid.inc.php';
-    } elseif ($auth && is_file(Config::get('install_dir') . "/includes/html/graphs/$type/$subtype.inc.php")) {
-        include Config::get('install_dir') . "/includes/html/graphs/$type/$subtype.inc.php";
-    } elseif ($auth && is_file(Config::get('install_dir') . "/includes/html/graphs/$type/generic.inc.php")) {
-        include Config::get('install_dir') . "/includes/html/graphs/$type/generic.inc.php";
+        include LibrenmsConfig::get('install_dir') . '/includes/html/graphs/customoid/customoid.inc.php';
+    } elseif ($auth && is_file(LibrenmsConfig::get('install_dir') . "/includes/html/graphs/$type/$subtype.inc.php")) {
+        include LibrenmsConfig::get('install_dir') . "/includes/html/graphs/$type/$subtype.inc.php";
+    } elseif ($auth && is_file(LibrenmsConfig::get('install_dir') . "/includes/html/graphs/$type/generic.inc.php")) {
+        include LibrenmsConfig::get('install_dir') . "/includes/html/graphs/$type/generic.inc.php";
     } else {
         graph_error("$type*$subtype Graph Template Missing", "$type*$subtype");
     }
@@ -73,7 +73,7 @@ try {
         echo "<div class='infobox'>";
         echo "<p style='font-size: 16px; font-weight: bold;'>RRDTool Command</p>";
         echo "<pre class='rrd-pre'>";
-        echo escapeshellcmd('rrdtool ' . Rrd::buildCommand('graph', Config::get('temp_dir') . '/' . Str::random(), $rrd_options));
+        echo escapeshellcmd('rrdtool ' . Rrd::buildCommand('graph', LibrenmsConfig::get('temp_dir') . '/' . Str::random(), $rrd_options));
         echo '</pre>';
         try {
             Rrd::graph($rrd_options, $env);
